/////////////////////////////////////////////////////////////////////
// Momentum-Start.mq4
// Version 1.1
// Copyright  2007, Bruce Hellstrom (brucehvn)
// bhweb@speakeasy.net
// http://www.metaquotes.net
/////////////////////////////////////////////////////////////////////

/*
    This indicator was developed as an analysis tool to go with Auslanco's
    Momentum strategies.  Because Auslanco pays a lot of attention to what the
    momentum indicator is pointing to at the beginning of a new bar, this indicator
    captures the momentum reading at that time and displays it to the user.

    The display is a series of alternating colored short line segments.  Each
    segment spans just 2 bars.  Each individual line segment is showing what the
    momentum reading was at the beginning of the most recent bar of the two.

    A standard momentum line is drawn in a light colored dotted line so you can
    see the actual momentum readings when they differ.

    I wouldn't expect people to have this indicator on the charts all the time, but
    it can be used as an analysis tool to verify the validity of momentum readings
    and to remember what it said at the beginning of various bars.
    
    Input Parameters
    MomPeriod - The period to use for the momentum calculation
    
    Revision History
    Version 1.0
      * Initial release
    
    Version 1.1 (18 Nov 2007)
      * Changed name
      * Added support for 2 hour charts
*/    


#property copyright "Copyright  2007, Bruce Hellstrom (brucehvn)"
#property link      "http: //www.metaquotes.net/"

#property indicator_separate_window
#property indicator_buffers 4
#property indicator_color1 Blue
#property indicator_style1 STYLE_SOLID
#property indicator_width1 2
#property indicator_color2 Gold
#property indicator_style2 STYLE_SOLID
#property indicator_width2 2
#property indicator_color3 LimeGreen
#property indicator_style3 STYLE_SOLID
#property indicator_width3 2
#property indicator_color4 Silver
#property indicator_style4 STYLE_DOT
#property indicator_width4 1
#property indicator_level1 0.0
#property indicator_levelcolor Red
#property indicator_levelwidth 1
#property indicator_levelstyle STYLE_SOLID

#define INDICATOR_VERSION "v1.1"


// Input Parameters
extern int MomPeriod = 10;

// Buffers
double MomBuffer1[];
double MomBuffer2[];
double MomBuffer3[];
//double MomBuffer4[];
double MomBuffer5[];

// Other Variables
string ShortName;


/////////////////////////////////////////////////////////////////////
// Custom indicator initialization function
/////////////////////////////////////////////////////////////////////

int init() {

    IndicatorBuffers( 4 );
    SetIndexStyle( 0, DRAW_LINE, STYLE_SOLID, 2 );
    SetIndexBuffer( 0, MomBuffer1 );
    SetIndexDrawBegin( 0, MomPeriod );
    SetIndexStyle( 1, DRAW_LINE, STYLE_SOLID, 2 );
    SetIndexBuffer( 1, MomBuffer2 );
    SetIndexDrawBegin( 1, MomPeriod );
    SetIndexStyle( 2, DRAW_LINE, STYLE_SOLID, 2 );
    SetIndexBuffer( 2, MomBuffer3 );
    SetIndexDrawBegin( 2, MomPeriod );
    SetIndexStyle( 3, DRAW_LINE, STYLE_DOT, 1 );
    SetIndexBuffer( 3, MomBuffer5 );
    SetIndexDrawBegin( 3, MomPeriod );
    
    ShortName = "Momentum-Start-" + INDICATOR_VERSION + "(" + MomPeriod + ")";
    
    IndicatorShortName( ShortName );
    SetIndexLabel( 0, ShortName );
    SetIndexLabel( 1, ShortName );
    SetIndexLabel( 2, ShortName );
    SetIndexLabel( 3, ShortName );
    
    Print( ShortName );
    Print( "Copyright (c) 2007 - Bruce Hellstrom, bhweb@speakeasy.net" );
    
    return( 0 );
}

/////////////////////////////////////////////////////////////////////
// Custom indicator deinitialization function
/////////////////////////////////////////////////////////////////////

int deinit() {
    return( 0 );
}

/////////////////////////////////////////////////////////////////////
// Indicator Logic run on every tick
/////////////////////////////////////////////////////////////////////

int start() {
    
    int counted_bars = IndicatorCounted();
    
    // Check for errors
    if ( counted_bars < 0 ) {
        return( -1 );
    }

    // Last bar will be recounted
    if ( counted_bars > 0 ) {
        counted_bars--;
    }
    
    // Get the upper limit
    int limit = Bars - counted_bars;
    
    for ( int ictr = 0; ictr < limit; ictr++ ) {
        int ChartPeriod = Period();
        switch( ChartPeriod ) {
            case PERIOD_M1:
                int buffernum = TimeMinute( Time[ictr] ) % 3;
                break;

            case PERIOD_M5:
                buffernum = ( TimeMinute( Time[ictr] ) / 5 ) % 3;
                break;

            case PERIOD_M15:
                int hr = TimeHour( Time[ictr] ) % 3;
                int min = TimeMinute( Time[ictr] ) / 15;
                buffernum = ( min + ( 4 * hr ) ) % 3;
                break;
                
            case PERIOD_M30:
                hr = TimeHour( Time[ictr] ) % 3;
                min = TimeMinute( Time[ictr] ) / 30;
                buffernum = ( min + ( 2 * hr ) ) % 3;
                break;
                
            case PERIOD_H1:
                buffernum = TimeHour( Time[ictr] ) % 3;
                break;
                
            case PERIOD_H4:
                buffernum = ( TimeHour( Time[ictr] ) / 4 ) % 3;
                break;
                
            case PERIOD_D1:
                int day = TimeDayOfYear( Time[ictr] );
                int tradeday = ( ( day / 7 ) * 5 ) + TimeDayOfWeek( Time[ictr] );
                buffernum = tradeday % 3;
                break;
                
            case PERIOD_W1:
                buffernum = ( TimeDayOfYear( Time[ictr] ) / 7 ) % 3;
                break;
                
            case PERIOD_MN1:
                buffernum = TimeMonth( Time[ictr] ) % 3;
                break;
                
            case 120: // 2 hour charts
                buffernum = ( TimeHour( Time[ictr] ) / 2 ) % 3;
                break;
                
            case 480: // 8 hour charts
                day = TimeDayOfYear( Time[ictr] );
                tradeday = ( ( ( day / 7 ) * 5 ) + TimeDayOfWeek( Time[ictr] ) ) % 3;
                hr = TimeHour( Time[ictr] ) / 8;
                buffernum = ( hr + ( 3 * tradeday ) ) % 3;
                break;
                
            case 720: // 12 hour charts
                day = TimeDayOfYear( Time[ictr] );
                tradeday = ( ( ( day / 7 ) * 5 ) + TimeDayOfWeek( Time[ictr] ) ) % 3;
                hr = TimeHour( Time[ictr] ) / 12;
                buffernum = ( hr + ( 2 * tradeday ) ) % 3;
                break;
                
            default:
                buffernum = -1;
                break;
        }
        
        if ( buffernum == -1 ) {
            Print( "Unsupported time period on chart: ", ChartPeriod );
            return( -1 );
        }
        
        double Mom1 = Open[ictr] - Close[ictr + MomPeriod];
        double Mom2 = Close[ictr + 1] - Close[ictr + MomPeriod + 1];
        
        switch( buffernum ) {
            case 0:
                MomBuffer1[ictr] = Mom1;
                MomBuffer1[ictr + 1] = Mom2;
                break;
                
            case 1:
                MomBuffer2[ictr] = Mom1;
                MomBuffer2[ictr + 1] = Mom2;
                break;

            case 2:
                MomBuffer3[ictr] = Mom1;
                MomBuffer3[ictr + 1] = Mom2;
                break;
        }
        
        MomBuffer5[ictr] = Close[ictr] - Close[ictr + MomPeriod];
    }

    return( 0 );
}

